@@ -1,6 +1,6 @@
 /* 
- * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011
- * Free Software Foundation, Inc.
+ * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011,
+ * 2012 Free Software Foundation, Inc.
  * 
  * This file is part of GNU libmatheval
  * 
@@ -162,7 +162,7 @@ math_step(double x)
 	/* 
 	 * Calculate step function value.
 	 */
-	return (x < 0) ? 0 : 1;
+	return MATH_ISNAN(x) ? x : ((x < 0) ? 0 : 1);
 }
 
 double
@@ -171,7 +171,7 @@ math_delta(double x)
 	/* 
 	 * Calculate delta function value.
 	 */
-	return (x == 0) ? MATH_INFINITY : 0;
+	return MATH_ISNAN(x) ? x : ((x == 0) ? MATH_INFINITY : 0);
 }
 
 double
@@ -180,5 +180,5 @@ math_nandelta(double x)
 	/* 
 	 * Calculate modified delta function value.
 	 */
-	return (x == 0) ? MATH_NAN : 0;
+	return MATH_ISNAN(x) ? x : ((x == 0) ? MATH_NAN : 0);
 }
