@@ -1,6 +1,6 @@
 /* 
- * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011
- * Free Software Foundation, Inc.
+ * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011,
+ * 2012 Free Software Foundation, Inc.
  * 
  * This file is part of GNU libmatheval
  * 
@@ -48,6 +48,12 @@
 #define MATH_NAN (0.0/0.0)
 #endif
 
+#ifdef isnan
+#define MATH_ISNAN(x) isnan(x)
+#else
+#define MATH_ISNAN(x) ((x) != (x))
+#endif
+
 /* Calculate cotangent of value x.  */
 double          math_cot(double x);
 
